pub struct WritableCrc<'c, W: Width>(pub Digest<'c, W>);Expand description
Wrapper around any crc::Digest (typically hashes) that implements embedded_io::Write
to send data into a digest.
Tuple Fields
0: Digest<'c, W>Trait Implementations
Sourceimpl<W: Width> ErrorType for WritableCrc<'_, W>
impl<W: Width> ErrorType for WritableCrc<'_, W>
Sourcetype Error = Infallible
type Error = Infallible
Error type of all the IO operations on this type.
Sourceimpl Write for WritableCrc<'_, u32>
impl Write for WritableCrc<'_, u32>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Self::Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Self::Error>
Write a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<(), Self::Error>
fn flush(&mut self) -> Result<(), Self::Error>
Flush this output stream, blocking until all intermediately buffered contents reach their destination.
Sourceimpl Write for WritableCrc<'_, u64>
impl Write for WritableCrc<'_, u64>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Self::Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Self::Error>
Write a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<(), Self::Error>
fn flush(&mut self) -> Result<(), Self::Error>
Flush this output stream, blocking until all intermediately buffered contents reach their destination.